@@ -1,10 +1,10 @@
 /* $id$
  *
- * GNOME Internet Radio Locator
+ * GNOME Internet Radio Locator for GNOME 3
  *
  * Copyright (C) 2014, 2015, 2016, 2017, 2018  Ole Aamot Software
  *
- * Author: Ole Aamot <oka@oka.no>
+ * Author: Ole Aamot <ole@gnome.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -513,7 +513,7 @@ GNOMEInternetRadioLocatorStationInfo *gnome_internet_radio_locator_station_load_
 					     gpointer data)
 {
 	GNOMEInternetRadioLocatorStationInfo *gstation;
-	gstation = gnome_internet_radio_locator_station_load_from_file (head, "http://gnome-internet-radio-locator.src.oka.no/gnome_internet_radio_locator.xml");
+	gstation = gnome_internet_radio_locator_station_load_from_file (head, "http://gnome-internet-radio-locator.src.ole.org/gnome_internet_radio_locator.xml");
 	return gstation;
 }
 
